@@ -120,9 +120,9 @@ void gnome_font_face_ps_embed (GnomeFontPsObject *pso);
 
 /* Private face loader */
 
-gboolean gff_load (GnomeFontFace *face);
+gboolean gnome_font_face_load (GnomeFontFace *face);
 
-#define GFF_LOADED(f) ((f)->ft_face || gff_load ((GnomeFontFace *) f))
+#define GFF_LOADED(f) ((f)->ft_face || gnome_font_face_load ((GnomeFontFace *) f))
 
 
 /*
