@@ -215,15 +215,15 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 	c = strrchr ((gchar *) fc_file, '.');
 	if (!c)
 		return NULL;
-	else if (g_strcasecmp (c, ".pfb") == 0)
+	else if (g_ascii_strcasecmp (c, ".pfb") == 0)
 		font_type = GP_FONT_ENTRY_TYPE1;
-	else if (g_strcasecmp (c, ".pfa") == 0)
+	else if (g_ascii_strcasecmp (c, ".pfa") == 0)
 		font_type = GP_FONT_ENTRY_TYPE1;
-	else if (g_strcasecmp (c, ".ttf") == 0)
+	else if (g_ascii_strcasecmp (c, ".ttf") == 0)
 		font_type = GP_FONT_ENTRY_TRUETYPE;
-	else if (g_strcasecmp (c, ".ttc") == 0)
+	else if (g_ascii_strcasecmp (c, ".ttc") == 0)
 		font_type = GP_FONT_ENTRY_TRUETYPE;
-	else if (g_strcasecmp (c, ".font") == 0) /* See #102400 */
+	else if (g_ascii_strcasecmp (c, ".font") == 0) /* See #102400 */
 		font_type = GP_FONT_ENTRY_TRUETYPE;
 	else {
 		return NULL;
