@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #include <config.h>
 
 #include <libgnomeprint/gnome-print-filter.h>
@@ -124,9 +125,13 @@ gnome_print_filter_set_property (GObject *object, guint n, const GValue *v,
 		gnome_print_filter_changed (f);
 		break;
 	case PROP_CONTEXT:
-		if (f->priv->pc) g_object_unref (G_OBJECT (f->priv->pc));
+		if (f->priv->pc)
+			g_object_remove_weak_pointer (G_OBJECT (f->priv->pc),
+				(gpointer *)&(f->priv->pc));
 		f->priv->pc = g_value_get_object (v);
-		if (f->priv->pc) g_object_ref (G_OBJECT (f->priv->pc));
+		if (f->priv->pc)
+			g_object_add_weak_pointer (G_OBJECT (f->priv->pc),
+				(gpointer *)&(f->priv->pc));
 		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (object, n, pspec);
 	}
@@ -151,7 +156,10 @@ gnome_print_filter_reset (GnomePrintFilter *f)
 	for (i = 1; i < n; i++)
 		gnome_print_meta_reset (g_ptr_array_index (f->priv->meta, i - 1));
 
-	f->priv->pc = NULL;
+	if (f->priv->pc) {
+		g_object_unref (G_OBJECT (f->priv->pc));
+		f->priv->pc = NULL;
+	}
 }
 
 static gint
@@ -164,8 +172,6 @@ beginpage_impl (GnomePrintFilter *f, GnomePrintContext *pc, const guchar *name)
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (!gnome_print_filter_haspage (f) || (f->priv->pc == pc), GNOME_PRINT_ERROR_BADVALUE);
 
-	f->priv->pc = pc;
-
 	/* Check if there are filters inside this filter. */
 	n = gnome_print_filter_count_filters (f);
 	if (n) {
@@ -239,9 +245,7 @@ showpage_impl (GnomePrintFilter *f)
 		}
 		g_ptr_array_free (f->priv->meta_bin, TRUE);
 		f->priv->meta_bin = NULL;
-		g_object_set (G_OBJECT (f->priv->pc), "filter", f_old, NULL);
-		f->priv->pc = NULL;
-		return GNOME_PRINT_OK;
+		goto reset_filter;
 	}
 
 	/* Check if this filter has successors */
@@ -249,13 +253,11 @@ showpage_impl (GnomePrintFilter *f)
 	if (!n) {
 		if (!f->priv->bin) {
 			gnome_print_showpage_real (f->priv->pc);
-			f->priv->pc = NULL;
 			return GNOME_PRINT_OK;
 		}
 		n = gnome_print_filter_count_successors (f->priv->bin);
 		if (!n) {
 			gnome_print_showpage_real (f->priv->pc);
-			f->priv->pc = NULL;
 			return GNOME_PRINT_OK;
 		}
 		gnome_print_showpage_real (GNOME_PRINT_CONTEXT (
@@ -268,9 +270,7 @@ showpage_impl (GnomePrintFilter *f)
 		}
 		g_object_unref (G_OBJECT (f->priv->bin->priv->meta_bin_last));
 		f->priv->bin->priv->meta_bin_last = NULL;
-		g_object_set (G_OBJECT (f->priv->pc), "filter", f_old, NULL);
-		f->priv->pc = NULL;
-		return GNOME_PRINT_OK;
+		goto reset_filter;
 	}
 
 	/* This filter has successors */
@@ -285,8 +285,11 @@ showpage_impl (GnomePrintFilter *f)
 		gnome_print_meta_render (meta, f->priv->pc);
 		gnome_print_meta_reset (meta);
 	}
+
+reset_filter :
 	g_object_set (G_OBJECT (f->priv->pc), "filter", f_old, NULL);
-	f->priv->pc = NULL;
+	if (NULL != f_old)
+		g_object_unref (G_OBJECT (f_old));
 	return GNOME_PRINT_OK;
 }
 
@@ -763,6 +766,10 @@ reset_impl (GnomePrintFilter *f)
 					gnome_print_filter_get_successor (f->priv->bin, i));
 		return;
 	}
+	if (f->priv->pc) {
+		g_object_unref (G_OBJECT (f->priv->pc));
+		f->priv->pc = NULL;
+	}
 }
 
 void
@@ -818,6 +825,11 @@ gnome_print_filter_finalize (GObject *object)
 		while (f->priv->successors)
 			gnome_print_filter_remove_predecessor (
 				g_ptr_array_index (f->priv->successors, 0), f);
+		if (f->priv->pc) {
+			g_object_remove_weak_pointer (G_OBJECT (f->priv->pc),
+				(gpointer *)&(f->priv->pc));
+			f->priv->pc = NULL;
+		}
 		g_free (f->priv);
 		f->priv = NULL;
 	}
@@ -1289,6 +1301,8 @@ gnome_print_filter_beginpage (GnomePrintFilter *f, GnomePrintContext *pc,
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (!gnome_print_filter_haspage (f) || (pc == f->priv->pc), GNOME_PRINT_ERROR_UNKNOWN);
 
+	if (!f->priv->pc)
+		g_object_set (G_OBJECT (f), "context", pc, NULL);
 	return GPFGC (f)->beginpage ?
 		GPFGC (f)->beginpage (f, pc, name) : GNOME_PRINT_OK;
 }
