@@ -235,6 +235,7 @@ font_from_pango_font (PangoFont *font)
 	FcChar8 *filename;
 	gint id;
 	gdouble size;
+	FcResult result;
 	
 	if (!PANGO_IS_FC_FONT (font))
 		return NULL;
@@ -246,13 +247,16 @@ font_from_pango_font (PangoFont *font)
       
 	if (FcPatternGetInteger (fcfont->font_pattern, FC_INDEX, 0, &id) != FcResultMatch)
 		return NULL;
-	
-	if (FcPatternGetDouble (fcfont->font_pattern, FC_SIZE, 0, &size) != FcResultMatch)
-		return NULL;
-	if (FcPatternGetDouble (fcfont->font_pattern, FC_SIZE, 0, &size) != FcResultMatch &&
-	    FcPatternGetDouble (fcfont->font_pattern, FC_PIXEL_SIZE, 0, &size) != FcResultMatch)
-		return NULL;
 
+	/* Look for either FC_SIZE or FC_PIXEL_SIZE, since the resolution is 72,
+	 * they are the same thing.
+	 */
+	result = FcPatternGetDouble (fcfont->font_pattern, FC_SIZE, 0, &size);
+	if (result == FcResultNoMatch)
+		result = FcPatternGetDouble (fcfont->font_pattern, FC_PIXEL_SIZE, 0, &size);
+	if (result != FcResultMatch)
+		return NULL;
+	 
 	return gnome_font_find_from_filename (filename, id, size);
 }
 
