@@ -456,7 +456,7 @@ gnome_print_ps2_show (GnomePrintPs2 *ps2, GnomePosGlyphList const *pgl, int star
 static gint
 gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphList *gl)
 {
-	static gdouble id[] = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
+	static gdouble const id[] = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
 	GnomePrintPs2 *ps2;
 	GnomePosGlyphList *pgl;
 	gboolean identity;
