@@ -106,7 +106,10 @@ gpa_config_printer_modified (GPANode *node)
 	config = GPA_CONFIG (node->parent);
 	printer = GPA_REFERENCE_REFERENCE (config->printer);
 	
-	if (printer == GPA_REFERENCE_REFERENCE (GPA_SETTINGS (GPA_REFERENCE_REFERENCE (config->settings))->printer)) {
+	if (config->settings != NULL && 
+	    GPA_REFERENCE_REFERENCE (config->settings) != NULL &&
+	    GPA_SETTINGS (GPA_REFERENCE_REFERENCE (config->settings))->printer != NULL &&
+	    printer == GPA_REFERENCE_REFERENCE (GPA_SETTINGS (GPA_REFERENCE_REFERENCE (config->settings))->printer)) {
 		return;
 	}
 
@@ -206,20 +209,17 @@ gpa_config_new_error:
 static GPANode *
 gpa_config_duplicate (GPANode *node)
 {
-	GPAConfig *config, *new;
+	GPAConfig *config = NULL, *new;
+	GPANode *settings = NULL;
 
 	config = GPA_CONFIG (node);
 
-	new = (GPAConfig *) gpa_node_new (GPA_TYPE_CONFIG, gpa_node_id (node));
+	settings = gpa_node_duplicate 
+		(GPA_REFERENCE_REFERENCE(config->settings));
 
-	if (config->printer)
-		new->printer = gpa_node_attach (GPA_NODE (new), 
-						gpa_node_duplicate (config->printer));
-
-#warning "FIXME: something leaks here."
-	if (config->settings)
-		new->settings = gpa_node_attach (GPA_NODE (new), 
-						 gpa_node_duplicate (config->settings));
+	new = gpa_config_new_full 
+		(GPA_PRINTER (GPA_REFERENCE_REFERENCE(config->printer)), 
+		 GPA_SETTINGS (settings));
 
 	return GPA_NODE (new);
 }
