@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: crc32.c,v 1.2 2004/09/10 18:59:06 jody Exp $ */
+/* $Id: crc32.c,v 1.3 2005/01/04 20:10:46 jody Exp $ */
 /* @(#)crc32.c 1.5 03/01/08 SMI */
 
 /*
@@ -47,7 +47,7 @@
 #include "sft.h"
 #include "crc32.h"
 
-static uint32 crcTable[256] = {
+static guint32 crcTable[256] = {
   0x00000000UL, 0x77073096UL, 0xEE0E612CUL, 0x990951BAUL, 0x076DC419UL, 0x706AF48FUL, 0xE963A535UL, 0x9E6495A3UL,
   0x0EDB8832UL, 0x79DCB8A4UL, 0xE0D5E91EUL, 0x97D2D988UL, 0x09B64C2BUL, 0x7EB17CBDUL, 0xE7B82D07UL, 0x90BF1D91UL,
   0x1DB71064UL, 0x6AB020F2UL, 0xF3B97148UL, 0x84BE41DEUL, 0x1ADAD47DUL, 0x6DDDE4EBUL, 0xF4D4B551UL, 0x83D385C7UL,
@@ -82,10 +82,10 @@ static uint32 crcTable[256] = {
   0xB3667A2EUL, 0xC4614AB8UL, 0x5D681B02UL, 0x2A6F2B94UL, 0xB40BBE37UL, 0xC30C8EA1UL, 0x5A05DF1BUL, 0x2D02EF8DUL
 };
 
-uint32 crc32(const void *ptr, size_t len)
+guint32 crc32(const void *ptr, size_t len)
 {
-    uint32 crc = 0xFFFFFFFF;
-    const byte *bp = (const byte *) ptr;
+    guint32 crc = 0xFFFFFFFF;
+    const guint8 *bp = (const guint8 *) ptr;
     size_t i;
 
     for (i=0; i<len; i++) {
