@@ -37,6 +37,9 @@
 #include <libgnomeprint/gnome-font.h>
 #include <libgnomeprint/gnome-font-private.h>
 #include <libgnomeprint/gnome-fontmap.h>
+#ifdef G_OS_WIN32
+#include <winsock2.h>
+#endif
 
 #define FONT_SAMPLE_SIZE 12.0
 
@@ -68,7 +71,9 @@ static struct poptOption options[] = {
 	  "Max number of fonts to embed",    NULL},
 	{ "output",    'o', POPT_ARG_STRING, &options_output,   0,
 	  "Specify the output file",  NULL},
+#ifndef USE_POPT_DLL
 	POPT_AUTOHELP
+#endif
 	{ NULL }
 };
 
@@ -645,12 +650,14 @@ handle_sigsegv (int i)
 int
 main (int argc, const char *argv[])
 {
+#ifndef G_OS_WIN32
 	struct sigaction sig;
 
 	/* We need to catch crashes */
 	sig.sa_handler = handle_sigsegv;
 	sig.sa_flags = 0;
 	sigaction (SIGSEGV, &sig, NULL);
+#endif
 	
 	check_options (argc, argv);
 
