@@ -25,6 +25,9 @@
 
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <popt.h>
 #include <string.h>
 #include <stdlib.h>
@@ -38,6 +41,9 @@ typedef enum {
 	BACKEND_META,
 #ifdef ENABLE_SVG
 	BACKEND_SVG,
+#endif
+#ifdef HAVE_GDI
+	BACKEND_GDI,
 #endif
 	BACKEND_UNKNOWN
 } BackendType;
@@ -57,7 +63,9 @@ static struct poptOption options[] = {
 	  "Replay a metafile rather than using an internal sequence", "metafile"},
 	{ "debug",    '\0', POPT_ARG_NONE, &debug, 0,
 	  "Print debugging output",          NULL},
+#ifndef USE_POPT_DLL
 	POPT_AUTOHELP
+#endif
 	{ NULL }
 };
 
@@ -107,15 +115,15 @@ my_draw_randomfig (GnomePrintContext *pc)
 	double max = 100.0;
 	gint ret = 0;
 
-	srandom (47);
+	g_random_set_seed (47);
 	
 	ret += gnome_print_gsave (pc);
 	
 	ret += gnome_print_newpath (pc);
 	ret += gnome_print_moveto (pc, 0, 0);
 	for (i = 80; 0 < i; i --) {
-		a = 1+(int) (max*rand()/(RAND_MAX+1.0));
-		b = 1+(int) (max*rand()/(RAND_MAX+1.0));
+		a = 1+(int) (max*g_random_double()/(RAND_MAX+1.0));
+		b = 1+(int) (max*g_random_double()/(RAND_MAX+1.0));
 		ret += gnome_print_lineto (pc, a, b);
 	}
 	ret += gnome_print_stroke (pc);
@@ -295,6 +303,7 @@ my_draw_text (GnomePrintContext *pc)
 			     font_name = "Arioso Bold";
 			     break;
 		     case 3:
+		     default:
 			     font_name = "Verdana Bold Italic";
 			     break;
 		     }
@@ -329,7 +338,7 @@ my_draw_glyphlist (GnomePrintContext *pc)
 {
 	GnomeGlyphList *gl;
 	GnomeFont *font;
-	gint ret;
+	gint ret = 0;
 	gchar *p, *end;
 
 	ret += gnome_print_beginpage (pc, "1");
@@ -519,7 +528,7 @@ main (int argc, const char * argv[])
 		gnome_print_context_close (gpc);
 		data = gnome_print_meta_get_buffer (GNOME_PRINT_META (gpc));
 		len  = gnome_print_meta_get_length (GNOME_PRINT_META (gpc));
-		f = fopen (output, "w");
+		f = fopen (output, "wb");
 		if (!f) {
 			g_warning ("Could not create %s\n", output);
 			return 1;
@@ -549,6 +558,14 @@ main (int argc, const char * argv[])
 		if (!gnome_print_config_set (config, "Settings.Engine.Backend.Driver", "gnome-print-svg"))
 			my_error ("gnome_print_config_set Printer-SVG");
 		break;
+#endif
+#ifdef HAVE_GDI
+	case BACKEND_GDI:
+		if (!gnome_print_config_set (config, "Settings.Engine.Backend.Driver", "gnome-print-gdi"))
+			/* my_error ("gnome_print_config_set Printer-GDI");
+			   set_value may return FALSE when the Driver is already gnome-print-gdi, in this
+			   case it's not an error. */;
+		break;
 #endif
 	case BACKEND_UNKNOWN:
 	default:
@@ -595,6 +612,9 @@ usage (gchar *error)
 		 "         -pdf\n"
 #ifdef ENABLE_SVG
 		 "         -svg\n"
+#endif
+#ifdef HAVE_GDI
+		 "         -gdi\n"
 #endif
 		 "         -meta\n\n"
 		 "    Valid drawing sequences are: 0 thru 999 fixme\n"
@@ -624,6 +644,10 @@ parse_command_line (int argc, const char ** argv, BackendType *backend,
 #ifdef ENABLE_SVG
 	else if (!strcmp ("svg", backend_str))
 		*backend = BACKEND_SVG;
+#endif
+#ifdef HAVE_GDI
+	else if (!strcmp ("gdi", backend_str))
+		*backend = BACKEND_GDI;
 #endif
 	else if (!strcmp ("meta", backend_str))
 		*backend = BACKEND_META;
@@ -635,7 +659,7 @@ parse_command_line (int argc, const char ** argv, BackendType *backend,
 	
 	if (replay_str && replay_str[0] != '\0') {
 		FILE *file;
-		file = fopen (replay_str, "r");
+		file = fopen (replay_str, "rb");
 		if (!file) {
 			g_print ("File \"%s\" could not be opened\n", replay_str);
 			exit (-1);
